#include "m_usart.h"

/*******************************************************************************************************************/
void Init_UART(void)
{
	// set baud rate
	UBRRH = (uint8_t)(UART_BAUD_CALC(UART_BAUD_RATE,F_OSC) >> 8);
	UBRRL = (uint8_t) UART_BAUD_CALC(UART_BAUD_RATE,F_OSC);

	// Enable receiver and transmitter; enable RX interrupt
	UCSRB = (1 << RXEN) | (1 << TXEN) | (1 << RXCIE);

	//asynchronous 8N1
	UCSRC = (1 << URSEL) | (3 << UCSZ0);
}

/*******************************************************************************************************************/
void uart_putc(uint8_t c)
{
	// wait until UDR ready
	while (!(UCSRA & (1 << UDRE)));
	UDR = c;    // send character
}

/*******************************************************************************************************************/
void uart_puts (uint8_t * ch)
{
	while (*ch)
		uart_putc (*ch++);
}

/*******************************************************************************************************************/
void CheckForReboot (uint8_t ch)
{
	static uint8_t	RXBuf[5] = { 0, 0, 0, 0, 0 };
	static uint8_t	RXIdx = 0;

	uart_putc (0x30 + (RXIdx & 0x03));

	RXBuf[RXIdx] = ch;
	RXIdx = (RXIdx + 1) & 0x03;

	if ((RXBuf[(RXIdx + 0) & 0x03] == 'B') &&
		(RXBuf[(RXIdx + 1) & 0x03] == 'O') &&
		(RXBuf[(RXIdx + 2) & 0x03] == 'O') &&
		(RXBuf[(RXIdx + 3) & 0x03] == 'T'))
	{
		EnableWatchDog ();
		for (;;)
			asm volatile ("nop");
	}
		
}

/*******************************************************************************************************************/
// To be used in main program !!
// USART RX interrupt
//ISR (SIG_UART_RECV)
//{
//}
